"""API endpoints."""

# API Endpoints
API_ENDPOINT_CLOUDDEVICES = "/api/cloud/v2/cloudDevices/getAll"

API_ENDPOINT_LOGIN = "/v3/users/login/v5"
API_ENDPOINT_LOGOUT = "/v3/users/logout/v2"
API_ENDPOINT_REFRESH_SESSION_ID = "/v3/apigateway/login"
API_ENDPOINT_SERVER_INFO = "/v3/configurations/system/info"

API_ENDPOINT_USER_ID = "/v3/userdevices/v1/token"
API_ENDPOINT_GROUP_DEFENCE_MODE = "/v3/userdevices/v1/group/defenceMode"
API_ENDPOINT_PAGELIST = "/v3/userdevices/v1/resources/pagelist"
API_ENDPOINT_SWITCH_DEFENCE_MODE = "/v3/userdevices/v1/group/switchDefenceMode"
API_ENDPOINT_OSD = "/v3/userdevices/v1/devices/"

API_ENDPOINT_PANORAMIC_DEVICES_OPERATION = "/v3/panoramicDevices/operation"
API_ENDPOINT_UPGRADE_DEVICE = "/v3/upgrades/v1/devices/"
API_ENDPOINT_SEND_CODE = "/v3/sms/nologin/checkcode"
API_ENDPOINT_2FA_VALIDATE_POST_AUTH = "/v3/users/checkcode/mt"
API_ENDPOINT_UNIFIEDMSG_LIST_GET = "/v3/unifiedmsg/list"
API_ENDPOINT_IOT_FEATURE = "/v3/iot-feature/feature/"
API_ENDPOINT_IOT_ACTION = "/v3/iot-feature/action/"
API_ENDPOINT_CALLING_NOTIFY = "/v3/calling/"
API_ENDPOINT_SPECIAL_BIZS_VOICES = "/v3/specialBizs/voices"
API_ENDPOINT_SPECIAL_BIZS_A1S = "/v3/specialBizs/A1S/"
API_ENDPOINT_SPECIAL_BIZS_V1_BATTERY = "/v3/specialBizs/v1/batteryDevices/"

API_ENDPOINT_ALARMINFO_GET = "/v3/alarms/v2/advanced"
API_ENDPOINT_V3_ALARMS = "/v3/alarms/"
API_ENDPOINT_SET_LUMINANCE = "/v3/alarms/device/alarmLight/"
API_ENDPOINT_ALARM_DEVICE_CHIME = "/v3/alarms/device/chime/"
API_ENDPOINT_REMOTE_UNLOCK = "/Video/1/DoorLockMgr/RemoteUnlockReq"
API_ENDPOINT_AUTOUPGRADE_SWITCH = "/v3/autoupgrade/v1/switch"
API_ENDPOINT_UPGRADE_RULE = "/v3/upgraderule"

API_ENDPOINT_DEVCONFIG_BY_KEY = "/v3/devconfig/v1/keyValue/"
API_ENDPOINT_DEVCONFIG_OP = "/v3/devconfig/op"
API_ENDPOINT_DEVCONFIG_MOTOR = "/v3/devconfig/motor"
API_ENDPOINT_CAM_AUTH_CODE = "/v3/devconfig/authcode/query/"

API_ENDPOINT_INTELLIGENT_APP = "/v3/intelligent-app/load/"

API_ENDPOINT_DEVICE_BASICS = "/v3/basics/v1/devices/"

API_ENDPOINT_DETECTION_SENSIBILITY = "/api/device/configAlgorithm"
API_ENDPOINT_DETECTION_SENSIBILITY_GET = "/api/device/queryAlgorithmConfig"
API_ENDPOINT_SENSITIVITY = "/v3/devconfig/v1/sensitivity/"
API_ENDPOINT_SET_DEFENCE_SCHEDULE = "/api/device/defence/plan2"
API_ENDPOINT_DEVICE_SWITCH_STATUS_LEGACY = "/api/device/switchStatus"
API_ENDPOINT_CAM_ENCRYPTKEY = "/api/device/query/encryptkey"
API_ENDPOINT_OFFLINE_NOTIFY = "/api/device/notify/switch"
API_ENDPOINT_CANCEL_ALARM = "/api/device/cancelAlarm"
API_ENDPOINT_DEVICE_SYS_OPERATION = "/api/device/v2/sysOper/"
API_ENDPOINT_DEVICE_STORAGE_STATUS = "/api/device/queryStorageStatus"
API_ENDPOINT_DEVICE_UPDATE_NAME = "/api/device/updateName"
API_ENDPOINT_DEVCONFIG_SECURITY_ACTIVATE = "/v3/devconfig/security/activate/"
API_ENDPOINT_DEVCONFIG_SECURITY_CHALLENGE = "/v3/devconfig/security/challenge/"
API_ENDPOINT_DEVICES_LOC = "/v3/devices/loc"
API_ENDPOINT_IOT_VIRTUAL_BIND = "/v3/iot-virtual-device/bindDevice"
API_ENDPOINT_DEVCONFIG_BASE = "/v3/devconfig"
API_ENDPOINT_USERDEVICES_TOKEN = "/v3/userdevices/token"
API_ENDPOINT_DEVICE_ACCESSORY_LINK = "/v3/devices/accessory/"
API_ENDPOINT_DOORLOCK_USERS = "/v3/doorlocks/"
API_ENDPOINT_IOT_FEATURE_PRODUCT_VOICE_CONFIG = "/v3/iot-feature/product/voice/config"
API_ENDPOINT_USERS_LBS_SUB_DOMAIN = "/v3/users/lbs/sub/domain"
API_ENDPOINT_SCD_APP_DEVICE_ADD = "/v3/scd/app/device/add"
API_ENDPOINT_REMOTE_UNBIND_PROGRESS = "/v3/remote/unbind/device/applicant/"
API_ENDPOINT_CREATE_PANORAMIC = "/api/panoramic/devices/pics/collect"
API_ENDPOINT_RETURN_PANORAMIC = "/api/panoramic/devices/pics"

# Videogo DeviceApi
API_ENDPOINT_DEVICES = "/v3/devices/"
API_ENDPOINT_SWITCH_STATUS = "/switchStatus"
API_ENDPOINT_SWITCH_OTHER = "/switch"
API_ENDPOINT_PTZCONTROL = "/ptzControl"
API_ENDPOINT_ALARM_SOUND = "/alarm/sound"
API_ENDPOINT_SWITCH_SOUND_ALARM = "/sendAlarm"
API_ENDPOINT_ALARM_SET_CHANNEL_WHISTLE = "/alarm/setChannelWhistle"
API_ENDPOINT_ALARM_SET_DEVICE_WHISTLE = "/alarm/setDeviceWhistle"
API_ENDPOINT_ALARM_STOP_WHISTLE = "/alarm/stopWhistle"
API_ENDPOINT_ALARM_GET_WHISTLE_STATUS_BY_CHANNEL = "/alarm/getWhistleStatusByChannel"
API_ENDPOINT_ALARM_GET_WHISTLE_STATUS_BY_DEVICE = "/alarm/getWhistleStatusByDevice"
API_ENDPOINT_DO_NOT_DISTURB = "/nodisturb"
API_ENDPOINT_VIDEO_ENCRYPT = "encryptedInfo/risk"
API_ENDPOINT_CHANGE_DEFENCE_STATUS = "/changeDefenceStatusReq"
API_ENDPOINT_DEVICES_P2P_INFO = "/v3/devices/v2/p2p"
API_ENDPOINT_USERDEVICES_P2P_INFO = "/v3/userdevices/v1/devices/p2p"
API_ENDPOINT_USERDEVICES_KMS = "/v3/userdevices/v1/devices/kms"
API_ENDPOINT_USERDEVICES_STATUS = "/v3/userdevices/v1/devices/status"
API_ENDPOINT_USERDEVICES_V2 = "/v3/userdevices/v2/devices"
API_ENDPOINT_USERDEVICES_SEARCH = "/v3/userdevices/v2/devices"
API_ENDPOINT_STREAMING_RECORDS = "/v3/streaming/records"
API_ENDPOINT_DEVICES_ENCRYPTKEY_BATCH = "/v3/devices/encryptkey/query/batch/risk"
API_ENDPOINT_MANAGED_DEVICE_BASE = "/v3/userdevices/v1/managed/"
API_ENDPOINT_SDCARD_BLACK_LEVEL = "/v3/devconfig/v1/sdcard/"
API_ENDPOINT_TIME_PLAN_INFOS = "/v3/devconfig/v2/plan"
API_ENDPOINT_FEEDBACK = "/v3/feedback/v2"
API_ENDPOINT_SHARE_ACCEPT = "/v3/share/accept"
API_ENDPOINT_SHARE_QUIT = "/v3/share/quit"
API_ENDPOINT_DEVICE_EMAIL_ALERT = "/v3/unifiedmsg/notify/switch/128"
API_ENDPOINT_DEVICES_AUTHENTICATE = "/v3/devices/authenticate/"
API_ENDPOINT_DEVICES_SET_SWITCH_ENABLE = "/setSwitchEnableReq"
API_ENDPOINT_SMARTHOME_OUTLET_LOG = (
    "/v3/smarthome/outlet/log/switch/from/{from}/to/{to}"
)
API_ENDPOINT_DEVICES_ASSOCIATION_LINKED_IPC = (
    "/v3/devices/association/linked/ipcList/byA1"
)

# MQTT
API_ENDPOINT_REGISTER_MQTT = "/v1/getClientId"
API_ENDPOINT_START_MQTT = "/api/push/start"
API_ENDPOINT_STOP_MQTT = "/api/push/stop"
